summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KKeyChooser.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KKeyChooser.java')
-rw-r--r--kdejava/koala/org/kde/koala/KKeyChooser.java54
1 files changed, 27 insertions, 27 deletions
diff --git a/kdejava/koala/org/kde/koala/KKeyChooser.java b/kdejava/koala/org/kde/koala/KKeyChooser.java
index c90616f3..8e23ae50 100644
--- a/kdejava/koala/org/kde/koala/KKeyChooser.java
+++ b/kdejava/koala/org/kde/koala/KKeyChooser.java
@@ -12,7 +12,7 @@ import org.kde.qt.TQWidget;
/**
- Configure dictionaries of key/action associations for KAccel and
+ Configure dictionaries of key/action associations for TDEAccel and
TDEGlobalAccel.
The class takes care of all aspects of configuration, including
handling key conflicts internally. Connect to the allDefault()
@@ -21,7 +21,7 @@ import org.kde.qt.TQWidget;
See {@link KKeyChooserSignals} for signals emitted by KKeyChooser
@author Nicolas Hadacek <hadacek@via.ecp.fr>
- @short Widget for configuration of KAccel and TDEGlobalAccel.
+ @short Widget for configuration of TDEAccel and TDEGlobalAccel.
@see KKeyDialog
*/
@@ -56,56 +56,56 @@ public class KKeyChooser extends TQWidget {
/**
\overload
@param parent parent widget
- @param coll the KActionCollection to configure
+ @param coll the TDEActionCollection to configure
@param bAllowLetterShortcuts Set to false if unmodified alphanumeric
keys ('A', '1', etc.) are not permissible shortcuts.
@short \overload
*/
- public KKeyChooser(KActionCollection coll, TQWidget parent, boolean bAllowLetterShortcuts) {
+ public KKeyChooser(TDEActionCollection coll, TQWidget parent, boolean bAllowLetterShortcuts) {
super((Class) null);
newKKeyChooser(coll,parent,bAllowLetterShortcuts);
}
- private native void newKKeyChooser(KActionCollection coll, TQWidget parent, boolean bAllowLetterShortcuts);
- public KKeyChooser(KActionCollection coll, TQWidget parent) {
+ private native void newKKeyChooser(TDEActionCollection coll, TQWidget parent, boolean bAllowLetterShortcuts);
+ public KKeyChooser(TDEActionCollection coll, TQWidget parent) {
super((Class) null);
newKKeyChooser(coll,parent);
}
- private native void newKKeyChooser(KActionCollection coll, TQWidget parent);
- public KKeyChooser(KAccel actions, TQWidget parent, boolean bAllowLetterShortcuts) {
+ private native void newKKeyChooser(TDEActionCollection coll, TQWidget parent);
+ public KKeyChooser(TDEAccel actions, TQWidget parent, boolean bAllowLetterShortcuts) {
super((Class) null);
newKKeyChooser(actions,parent,bAllowLetterShortcuts);
}
- private native void newKKeyChooser(KAccel actions, TQWidget parent, boolean bAllowLetterShortcuts);
- public KKeyChooser(KAccel actions, TQWidget parent) {
+ private native void newKKeyChooser(TDEAccel actions, TQWidget parent, boolean bAllowLetterShortcuts);
+ public KKeyChooser(TDEAccel actions, TQWidget parent) {
super((Class) null);
newKKeyChooser(actions,parent);
}
- private native void newKKeyChooser(KAccel actions, TQWidget parent);
+ private native void newKKeyChooser(TDEAccel actions, TQWidget parent);
public KKeyChooser(TDEGlobalAccel actions, TQWidget parent) {
super((Class) null);
newKKeyChooser(actions,parent);
}
private native void newKKeyChooser(TDEGlobalAccel actions, TQWidget parent);
- // KKeyChooser* KKeyChooser(KShortcutList* arg1,TQWidget* arg2,ActionType arg3,bool arg4); >>>> NOT CONVERTED
- // KKeyChooser* KKeyChooser(KShortcutList* arg1,TQWidget* arg2,ActionType arg3); >>>> NOT CONVERTED
- public KKeyChooser(KShortcutList arg1, TQWidget parent) {
+ // KKeyChooser* KKeyChooser(TDEShortcutList* arg1,TQWidget* arg2,ActionType arg3,bool arg4); >>>> NOT CONVERTED
+ // KKeyChooser* KKeyChooser(TDEShortcutList* arg1,TQWidget* arg2,ActionType arg3); >>>> NOT CONVERTED
+ public KKeyChooser(TDEShortcutList arg1, TQWidget parent) {
super((Class) null);
newKKeyChooser(arg1,parent);
}
- private native void newKKeyChooser(KShortcutList arg1, TQWidget parent);
+ private native void newKKeyChooser(TDEShortcutList arg1, TQWidget parent);
/**
Insert an action collection, i.e. add all its actions to the ones
already associated with the KKeyChooser object.
@short Insert an action collection, i.
*/
- public native boolean insert(KActionCollection arg1);
+ public native boolean insert(TDEActionCollection arg1);
/**
Insert an action collection, i.e. add all its actions to the ones
already associated with the KKeyChooser object.
@param title subtree title of this collection of shortcut.
@short Insert an action collection, i.
*/
- public native boolean insert(KActionCollection arg1, String title);
+ public native boolean insert(TDEActionCollection arg1, String title);
public native void syncToConfig(String sConfigGroup, TDEConfigBase pConfig, boolean bClearUnset);
/**
This function writes any shortcut changes back to the original
@@ -115,7 +115,7 @@ public class KKeyChooser extends TQWidget {
public native void commitChanges();
/**
This commits and then saves the actions to disk.
- Any KActionCollection objects with the xmlFile() value set
+ Any TDEActionCollection objects with the xmlFile() value set
will be written to an XML file. All other will be written
to the application's rc file.
@short This commits and then saves the actions to disk.
@@ -151,7 +151,7 @@ public class KKeyChooser extends TQWidget {
@short Checks whether the given shortcut conflicts with global keyboard shortcuts.
*/
- public static native boolean checkGlobalShortcutsConflict(KShortcut cut, boolean warnUser, TQWidget parent);
+ public static native boolean checkGlobalShortcutsConflict(TDEShortcut cut, boolean warnUser, TQWidget parent);
/**
Checks whether the given shortcut conflicts with standard keyboard shortcuts.
If yes, and the warnUser argument is true, warns the user and gives them a chance
@@ -164,26 +164,26 @@ public class KKeyChooser extends TQWidget {
@short Checks whether the given shortcut conflicts with standard keyboard shortcuts.
*/
- public static native boolean checkStandardShortcutsConflict(KShortcut cut, boolean warnUser, TQWidget parent);
+ public static native boolean checkStandardShortcutsConflict(TDEShortcut cut, boolean warnUser, TQWidget parent);
// void initGUI(ActionType arg1,bool arg2); >>>> NOT CONVERTED
- protected native boolean insert(KAccel arg1);
+ protected native boolean insert(TDEAccel arg1);
protected native boolean insert(TDEGlobalAccel arg1);
- protected native boolean insert(KShortcutList arg1);
+ protected native boolean insert(TDEShortcutList arg1);
protected native void buildListView(int iList, String title);
protected native void buildListView(int iList);
protected native void readGlobalKeys();
protected native void updateButtons();
protected native void fontChange(TQFont _font);
- protected native void setShortcut(KShortcut cut);
- protected native boolean isKeyPresent(KShortcut cut, boolean warnuser);
- protected native boolean isKeyPresent(KShortcut cut);
- // bool isKeyPresentLocally(const KShortcut& arg1,KKeyChooserItem* arg2,const TQString& arg3); >>>> NOT CONVERTED
+ protected native void setShortcut(TDEShortcut cut);
+ protected native boolean isKeyPresent(TDEShortcut cut, boolean warnuser);
+ protected native boolean isKeyPresent(TDEShortcut cut);
+ // bool isKeyPresentLocally(const TDEShortcut& arg1,KKeyChooserItem* arg2,const TQString& arg3); >>>> NOT CONVERTED
protected native void _warning(KKeySequence seq, String sAction, String sTitle);
protected native void slotNoKey();
protected native void slotDefaultKey();
protected native void slotCustomKey();
protected native void slotListItemSelected(TQListViewItem item);
- protected native void capturedShortcut(KShortcut cut);
+ protected native void capturedShortcut(TDEShortcut cut);
protected native void slotSettingsChanged(int arg1);
protected native void slotListItemDoubleClicked(TQListViewItem ipoTQListViewItem, TQPoint ipoTQPoint, int c);
/** Deletes the wrapped C++ instance */